pub enum VerificationM4Error {
WrongChipCount {
n_witness_chips: usize,
n_chips: usize,
},
Main(VerificationError),
ChipInstance {
chip_id: usize,
instance: usize,
source: VerificationError,
},
MissingInstances {
chip_id: usize,
n_instances: usize,
n_active: usize,
},
CallMismatch {
chip_id: usize,
row: usize,
caller: Option<(usize, usize)>,
call_index: usize,
word: usize,
passed: u64,
served: u64,
},
}Expand description
Reason a witness fails to satisfy an M4 constraint system.
A witness is the main chip’s value vector and one list of instance value vectors per chip. It must satisfy every chip’s local constraints on every instance, and serve every chip call with the instance that call names.
Variants